package com.persagy.proxy.adm.utils;

import cn.hutool.core.util.ArrayUtil;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.node.ArrayNode;
import com.fasterxml.jackson.databind.node.ObjectNode;
import com.persagy.dmp.basic.utils.JsonNodeUtils;

import java.util.List;

/**
 * ADM通用查询条件
 * @author Charlie Yu
 * @date 2021-08-16
 */
public class AdmEntityTransferUtil {

    /**
     * 转换为数据中台对象
     * @param objList
     * @return
     */
    public static ArrayNode toDmpMultiEntity(List objList) {
        return JsonNodeUtils.toArrayNode(objList, "infos", null);
    }

    /**
     * 转换为数据中台对象
     * @param obj
     * @return
     */
    public static JsonNode toDmpSingleEntity(Object obj) {
        return JsonNodeUtils.toObjectNode(obj, "infos", null);
    }

    /**
     * 转换为数据中心对象
     * @param array 数据中台对象
     * @param clazz 数据中心对象class
     * @param <T>
     * @return
     */
    public static <T> List<T> toAdmMultiEntity(List<Object> array, Class<T> clazz) {
        ArrayNode dataNode = JsonNodeUtils.toArrayNode(array, null, null);
        return toAdmMultiEntity(dataNode, clazz);
    }

    /**
     * 转换为数据中心对象
     * @param array
     * @param clazz
     * @param <T>
     * @return
     */
    public static <T> List<T> toAdmMultiEntity(ArrayNode array, Class<T> clazz) {
        if(ArrayUtil.isEmpty(array)) {
            return null;
        }
        // 转换属性名 TODO 目前只有创建时间和修改时间需要转换，后续有其他时通过建立映射在此转换即可
        for(int i = 0, j = array.size();i < j;i++) {
            JsonNode node = array.get(i);
            if(node != null && node.isObject()) {
                copyProperty((ObjectNode) node, "creationTime", "createTime");
                copyProperty((ObjectNode) node, "modifiedTime", "lastUpdate");
                copyProperty((ObjectNode) node, "objType", "objectType");
                removeProperty((ObjectNode)node);
            }
        }
        return JsonNodeUtils.toEntity(array, clazz, "infos");
    }

    /**
     * 转换为数据中心对象
     * @param node
     * @param clazz
     * @param <T>
     * @return
     */
    public static <T> T toAdmSingleEntity(ObjectNode node, Class<T> clazz) {
        // 转换属性名 TODO 目前只有创建时间和修改时间需要转换，后续有其他时通过建立映射在此转换即可
        copyProperty(node, "creationTime", "createTime");
        copyProperty(node, "modifiedTime", "lastUpdate");
        copyProperty(node, "objectType", "objType");
        removeProperty(node);
        return JsonNodeUtils.toEntity(node, clazz, "infos");
    }

    /**
     * 拷贝属性
     * @param dmpData 数据中台对象
     * @param srcProp 数据中台属性名
     * @param desProp 对应的数据中心属性名
     */
    private static void copyProperty(ObjectNode dmpData, String srcProp, String desProp) {
        if(dmpData == null) {
            return;
        }
        JsonNode value = dmpData.get(srcProp);
        if(value == null || value.isNull()) {
            return;
        }
        dmpData.set(desProp, value);
        dmpData.remove(srcProp);
    }

    /**
     * 删除掉数据中心不需要的属性
     * @param dmpData
     */
    private static void removeProperty(ObjectNode dmpData){
        dmpData.remove( "creator");
        dmpData.remove( "groupCode");
        dmpData.remove( "valid");
        dmpData.remove( "createApp");
        dmpData.remove( "virtualCodes");
        dmpData.remove( "updateApp");
    }
}
